#
# spec file for package alsa-plugins
#
# Copyright (c) 2020 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%if 0%{?suse_version} >= 1550
%define build_aaf 1
%else
%define build_aaf 0
%endif

Name:           alsa-plugins
Version:        1.2.2
Release:        1.55
Summary:        Extra Plug-Ins for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Url:            http://www.alsa-project.org/
Source:         ftp://ftp.alsa-project.org/pub/plugins/alsa-plugins-%{version}.tar.bz2
Source1:        baselibs.conf
BuildRequires:  libtool
BuildRequires:  pkgconfig(alsa) >= 1.1.6
%if %{build_aaf}
BuildRequires:  pkgconfig(avtp)
%endif
BuildRequires:  pkgconfig(dbus-1)
BuildRequires:  pkgconfig(jack) >= 0.98
BuildRequires:  pkgconfig(libavcodec)
BuildRequires:  pkgconfig(libavresample)
BuildRequires:  pkgconfig(libavutil)
BuildRequires:  pkgconfig(libpulse) >= 0.9.11
BuildRequires:  pkgconfig(samplerate)
BuildRequires:  pkgconfig(speexdsp) >= 1.2
%ifarch s390x
Recommends:     %{name}-32bit = %{version}
%endif
Requires:       %{name}-speexrate
Requires:       %{name}-upmix

%description
This is a meta package installing a few sub-packages for extra plug-ins
for ALSA library.

%package oss
Summary:        Plug-Ins for ALSA Library to Access OSS Devices
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description oss
This package contains I/O and control plugins to access OSS devices
for ALSA library.

%package upmix
Summary:        PCM Up-mix Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description upmix
This package contains a PCM filter plugin that performs multi-channel
upmixing for ALSA library.

%package vdownmix
Summary:        PCM Virtual Down-mix Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description vdownmix
This package contains a PCM filter plugin that performs virtual down-mixing
for ALSA library.

%package usb-stream
Summary:        PCM I/O Plug-In for ALSA Library to access USB USx2y audio
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description usb-stream
This package contains a PCM I/O plugin to access USB USx2y audio devices
for ALSA library.

%package arcam-av
Summary:        Arcam AV Amplifier Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description arcam-av
This package contains a control plugin to access Arcam AV amplifier device
for ALSA library.

%package jack
Summary:        JACK I/O Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries
Requires:       jack
%ifarch s390x
Recommends:     %{name}-jack-32bit = %{version}
%endif

%description jack
This package contains the JACK (Jack Audio Connection Kit) I/O plug-in
for ALSA library.

%package pulse
Summary:        Pulseaudio Plug-In for ALSA Library
License:        GPL-2.0-or-later AND LGPL-2.1-or-later
Group:          System/Libraries
Requires:       pulseaudio
%ifarch s390x
Recommends:     %{name}-pulse-32bit = %{version}
%endif

%description pulse
pulseaudio is a networked sound server for Linux and other Unix like
operating systems and Microsoft Windows. It is intended to be an
improved drop-in replacement for the Enlightened Sound Daemon (ESOUND).

This package contains the polypaudio I/O plug-in for ALSA library.

%package maemo
Summary:        Maemo Plug-Ins for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description maemo
This package contains ALSA-library plug-ins using maemo SDK for
Nokia 770.

%package samplerate
Summary:        Samplerate Plug-In for ALSA Library
License:        GPL-2.0-or-later
Group:          System/Libraries
%ifarch s390x
Recommends:     %{name}-samplerate-32bit = %{version}
%endif

%description samplerate
This package contains the sample rate converter plugin for ALSA
library using libsamplerate.

%package speex
Summary:        Speex Prerocessor Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries
%ifarch s390x
Recommends:     %{name}-speex-32bit = %{version}
%endif

%description speex
This package contains the Speex preprocessor plugin for ALSA
library using libspeexdsp.

%package a52
Summary:        A52 Output Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description a52
This package contains the A52 (aka AC3) output plug-in for ALSA library.

%package speexrate
Summary:        Rate Converter Plug-In for ALSA Library using Speex
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description speexrate
This package contains the sample rate converter plugin for ALSA
library using Speex sample rate converter.

%package lavrate
Summary:        Rate Converter Plug-In for ALSA Library using libavcodec
License:        LGPL-2.1-or-later
Group:          System/Libraries
Provides:       alsa-plugins-lavcrate = %{version}
Obsoletes:      alsa-plugins-lavcrate < %{version}

%description lavrate
This package contains the sample rate converter plugin for ALSA
library using libavcodec.

%package aaf
Summary:        AVTP Audio Format PCM Plug-In for ALSA Library
License:        LGPL-2.1-or-later
Group:          System/Libraries

%description aaf
This package contains the AVTP AUdio Format (AAF) I/O plug-in
for ALSA library.

%prep
%setup -q

%build
export AUTOMAKE_JOBS="%{?_smp_mflags}"
# autoreconf -fi
%configure --enable-maemo-plugin --enable-maemo-resource-manager \
    --with-speex=builtin
make %{?_smp_mflags}

%install
%make_install %{?_smp_mflags}
mkdir -p %{buildroot}%{_sysconfdir}/alsa/conf.d
touch %{buildroot}%{_sysconfdir}/alsa/conf.d/99-pulseaudio-default.conf
# modules don't need *.la files
find %{buildroot} -type f -name "*.la" -delete -print

%post pulse
if command -v setup-pulseaudio > /dev/null; then
    setup-pulseaudio --auto
fi
exit 0

%postun pulse
if command -v setup-pulseaudio > /dev/null; then
    setup-pulseaudio --auto
fi
exit 0

%files
%license COPYING

%files oss
%license COPYING
%doc doc/README-pcm-oss
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_ctl_oss.so
%{_libdir}/alsa-lib/libasound_module_pcm_oss.so
%dir %{_datadir}/alsa/alsa.conf.d
%{_datadir}/alsa/alsa.conf.d/50-oss.conf
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_sysconfdir}/alsa/conf.d/50-oss.conf

%files upmix
%license COPYING
%doc doc/upmix.txt
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_pcm_upmix.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/60-upmix.conf
%{_sysconfdir}/alsa/conf.d/60-upmix.conf

%files vdownmix
%license COPYING
%doc doc/vdownmix.txt
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_pcm_vdownmix.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/60-vdownmix.conf
%{_sysconfdir}/alsa/conf.d/60-vdownmix.conf

%files arcam-av
%license COPYING
%doc doc/README-arcam-av
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_ctl_arcam_av.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/50-arcam-av-ctl.conf
%{_sysconfdir}/alsa/conf.d/50-arcam-av-ctl.conf

%files speexrate
%license COPYING
%doc doc/speexrate.txt
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_rate_speexrate*.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/10-speexrate.conf
%{_sysconfdir}/alsa/conf.d/10-speexrate.conf

%files usb-stream
%license COPYING
%dir %{_libdir}/alsa-lib
%{_libdir}/alsa-lib/libasound_module_pcm_usb_stream.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/98-usb-stream.conf
%{_sysconfdir}/alsa/conf.d/98-usb-stream.conf

%files jack
%license COPYING
%doc doc/README-jack
%{_libdir}/alsa-lib/libasound_module_pcm_jack.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/50-jack.conf
%{_sysconfdir}/alsa/conf.d/50-jack.conf

%files pulse
%license COPYING
%doc doc/README-pulse
%{_libdir}/alsa-lib/libasound_module_ctl_pulse.so
%{_libdir}/alsa-lib/libasound_module_pcm_pulse.so
%{_libdir}/alsa-lib/libasound_module_conf_pulse.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/50-pulseaudio.conf
%{_sysconfdir}/alsa/conf.d/50-pulseaudio.conf
%{_sysconfdir}/alsa/conf.d/99-pulseaudio-default.conf.example
%ghost %{_sysconfdir}/alsa/conf.d/99-pulseaudio-default.conf

%files maemo
%license COPYING
%doc doc/README-maemo
%{_libdir}/alsa-lib/libasound_module_ctl_dsp_ctl.so
%{_libdir}/alsa-lib/libasound_module_pcm_alsa_dsp.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/98-maemo.conf
%{_sysconfdir}/alsa/conf.d/98-maemo.conf

%files samplerate
%license COPYING.GPL
%doc doc/samplerate.txt
%{_libdir}/alsa-lib/libasound_module_rate_samplerate*.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/10-samplerate.conf
%{_sysconfdir}/alsa/conf.d/10-samplerate.conf

%files speex
%license COPYING
%doc doc/speexdsp.txt
%{_libdir}/alsa-lib/libasound_module_pcm_speex.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/60-speex.conf
%{_sysconfdir}/alsa/conf.d/60-speex.conf

%files a52
%license COPYING
%doc doc/a52.txt
%{_libdir}/alsa-lib/libasound_module_pcm_a52.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/60-a52-encoder.conf
%{_sysconfdir}/alsa/conf.d/60-a52-encoder.conf

%files lavrate
%license COPYING
%doc doc/lavrate.txt
%{_libdir}/alsa-lib/libasound_module_rate_lavrate.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_fast.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_faster.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_high.so
%{_libdir}/alsa-lib/libasound_module_rate_lavrate_higher.so
%dir %{_datadir}/alsa/alsa.conf.d
%dir %{_sysconfdir}/alsa
%dir %{_sysconfdir}/alsa/conf.d
%{_datadir}/alsa/alsa.conf.d/10-rate-lav.conf
%{_sysconfdir}/alsa/conf.d/10-rate-lav.conf

%if %{build_aaf}
%files aaf
%license COPYING
%doc doc/aaf.txt
%{_libdir}/alsa-lib/libasound_module_pcm_aaf.so
%endif

%changelog
* Mon Oct  5 2020 tiwai@suse.de
- Placeholder for SLE15-SP3 sync: jsc#SLE-11987
  no functional changes at all
* Wed May  6 2020 tiwai@suse.de
- Split plugins in alsa-plugin package to each subpackage
  (boo#1171276):
  now alsa-plugins is a meta package that requires only the
  fundamental speexrate and upmix plugins
- Add documentation for aaf plugin
- Minor spec cleanups
* Fri Mar 13 2020 tiwai@suse.de
- Update to alsa-plugins 1.2.2:
  * upmix plugin code refactoring, m4 file update
* Fri Nov 15 2019 tiwai@suse.de
- Update to alsa-plugins 1.2.1:
  * pulse: Add DEVICE parameter
* Fri May 10 2019 tiwai@suse.de
- Update to alsa-plugins 1.1.9:
  Fixes for jack and maemo plugins, see
    https://www.alsa-project.org/wiki/Changes_v1.1.8_v1.1.9
  for details
* Mon Mar 25 2019 tiwai@suse.de
- Build alsa-plugins-aaf conditionally, not stop the whole builds
  for old distros
* Wed Mar 20 2019 olaf@aepfle.de
- Adjust BuildRequires to use pkgconfig
* Thu Jan 10 2019 jengelh@inai.de
- Drop idempotent %%if..%%endif guards.
* Tue Jan  8 2019 tiwai@suse.de
- Update to alsa-plugins 1.1.8:
  * A52 Output plugin:
    a52_close: set slave to NULL to avoid double pcm free in open fcn
  * AVTP Audio Format (AAF) PCM plugin
    aaf: AVTPDU transmission periodicity
    aaf: Implement Playback mode support
    aaf: Load configuration parameters
    aaf: Introduce plugin skeleton
    aaf: Tx multiple AVTPDUs per media clock tick
    aaf: Refactor timeout routines
    aaf: Refactor AVTPDU reception routines
    aaf: Refactor AVTPDU transmission routines
    aaf: Add presentation time tolerance
    aaf: do not free twice aaf - snd_pcm_close() is called from snd_pcm_ioplug_delete()
    aaf: Add support for direct read/write transfers
    aaf: Implement dump() ioplug callback
    aaf: Implement Capture mode support
    aaf: Prepare for Capture mode support
    aaf: Implement Playback mode support
    aaf: Load configuration parameters
    aaf: Introduce plugin skeleton
  * Documentation:
    aaf: AVTPDU transmission periodicity
    aaf: Tx multiple AVTPDUs per media clock tick
    aaf: Add presentation time tolerance
    doc: Fix typo in AAF doc
    aaf: Implement Capture mode support
    aaf: Implement Playback mode support
    aaf: Load configuration parameters
    aaf: Introduce plugin skeleton
  * Jack PCM plugin:
    Revert "jack: Fix leaks when jack_set_hw_constraint() fails"
  * OSS Mixer -> ALSA Control plugin:
    Revert "oss: Fix leaks when oss_hw_constraint() fails"
  * USB stream plugin:
    Revert "usb_stream: Fix leaks when us_set_hw_constraint() fails"
    pcm_usb_stream: fix signess issues
    pcm_usb_stream: remove unused parameter in snd_pcm_us_read()
    pcm_usb_stream: fix another leak in snd_pcm_us_open()
- Drop obsoleted patches:
  0001-pcm_usb_stream-fix-another-leak-in-snd_pcm_us_open.patch
  0002-pcm_usb_stream-remove-unused-parameter-in-snd_pcm_us.patch
  0003-pcm_usb_stream-fix-signess-issues.patch
  0004-a52_close-set-slave-to-NULL-to-avoid-double-pcm-free.patch
  0005-Revert-jack-Fix-leaks-when-jack_set_hw_constraint-fa.patch
  0006-Revert-usb_stream-Fix-leaks-when-us_set_hw_constrain.patch
  0007-Revert-oss-Fix-leaks-when-oss_hw_constraint-fails.patch
- Add a new subpackage alsa-plugins-aaf;
  currently built only for TW
* Fri Dec  7 2018 bjorn.lie@gmail.com
- Use ffmpeg-4 versions of pkgconfig(libav*).
* Thu Nov 15 2018 tiwai@suse.de
- Remove the old override configs as the updated setup-pulseaudio
  script should handle the new configs (bsc#1116153)
* Wed Oct 24 2018 tiwai@suse.de
- Backport of yet another regression fixes in upstream:
  0005-Revert-jack-Fix-leaks-when-jack_set_hw_constraint-fa.patch
  0006-Revert-usb_stream-Fix-leaks-when-us_set_hw_constrain.patch
  0007-Revert-oss-Fix-leaks-when-oss_hw_constraint-fails.patch
* Wed Oct 24 2018 tiwai@suse.de
- Backport upstream commits:
  fix memory leaks and other minor issues in usb_stream plugin,
  fix a regression (appearins in PulseAudio) with a52 plugin:
  0001-pcm_usb_stream-fix-another-leak-in-snd_pcm_us_open.patch
  0002-pcm_usb_stream-remove-unused-parameter-in-snd_pcm_us.patch
  0003-pcm_usb_stream-fix-signess-issues.patch
  0004-a52_close-set-slave-to-NULL-to-avoid-double-pcm-free.patch
* Wed Oct 17 2018 tiwai@suse.de
- Updated to alsa-plugins 1.1.7:
  * configure: add --with-alsaaddondir, add default config files for plugins
  * configure: change --with-alsaaddondir to --with-alsagconfdir and --with-alsalconfdir
  * samplerate: fix unused variable warning
  * Renamve rate-lavc to rate-lav
  * configure script cleanups / fixes
  * Add explicit -lpthread to *_LIBADD
  * usb_stream: Fix leaks when us_set_hw_constraint() fails
  * oss: Fix leaks when oss_hw_constraint() fails
  * jack: Fix leaks when jack_set_hw_constraint() fails
  * a52: Fix leaks when a52_set_hw_constraint() fails
  * jack: Only allow ALSA periods multiple of JACKd period
  * jack: Allow build with older alsa-lib
  * jack: Update poll_fd also in draining state
  * jack: Avoid call to snd_pcm_avail_update() from JACK thread
- Renamed subpackage alsa-plugins-lavcrate to alsa-plugins-lavrate
* Fri May  4 2018 olaf@aepfle.de
- Use ffmpeg3 versions of pkgconfig(libav*)
* Mon Apr 23 2018 bjorn.lie@gmail.com
- Replace libavcodec-devel with pkgconfig(libavcodec),
  pkgconfig(libavutil) and pkgconfig(libavresample) BuildRequires
  and version them to less than the symbol versions provided by
  ffmpeg4 branch until upstream catches up. Currently provided by
  new ffmpeg3 compatability package.
* Wed Apr  4 2018 tiwai@suse.de
- Update to alsa-plugins 1.1.6:
  * Change FSF address (Franklin Street)
  * jack: Write only valid values to the internal hw_ptr
  * jack: Use boundary as hw_ptr wrap around
  * jack: Do not Xrun the ALSA buffer
  * jack: Report Xruns to user application
  * jack: Use correct parameter order for snd_pcm_areas_silence()
- Remove the build conditions for too old distros
- Use %%license file tag
- Enable avcodec build for SLE15, too
* Tue Nov 14 2017 tiwai@suse.de
- Update to alsa-plugins 1.1.5:
  * pulse: prevent double-free when pulse_hw_constraint returns
    error
* Tue Aug 29 2017 tiwai@suse.de
- Disable avcodec-related plugins for SLE packages
* Tue May 16 2017 tiwai@suse.de
- Update to alsa-plugins 1.1.4:
  * extend configure script to disable more stuff
  * including previous fix for libavcodec
- Obsoleted patch:
  0001-configure-Fix-detection-of-avcodec.h.patches
* Wed May  3 2017 tiwai@suse.de
- Fix the detection of libavcodec header files:
  0001-configure-Fix-detection-of-avcodec.h.patches
- Enable the build of a52 and lavcrate plugins for openSUSE
* Fri Dec  9 2016 zaitor@opensuse.org
- Own alsa-lib dir, needed due to changes in alsa.
* Thu Mar 31 2016 tiwai@suse.de
- Update to alsa-plugins 1.1.1:
  including all previous fixes, fixes of a52 plugin for the recent
  ffmpeg versions
- Delete obsoleted patches:
  0001-speex-Add-missing-include-config.h.patch
  0002-a52-fix-reported-input-channel-order.patch
  0003-pph-include-config.h-from-rate_speexrate.c.patch
* Wed Feb  3 2016 tiwai@suse.de
- Backport upstream fixes: build fixes with the recent ffmpeg
  0001-speex-Add-missing-include-config.h.patch
  0002-a52-fix-reported-input-channel-order.patch
  0003-pph-include-config.h-from-rate_speexrate.c.patch
- Drop the obsoleted patch:
  alsa-plugins-include-config.h.patch
* Wed Nov 25 2015 tiwai@suse.de
- Add supplements to 32bit packages to be fetched automatically
  (bsc#956402)
* Mon Nov  9 2015 tiwai@suse.de
- Update to alsa-plugins 1.1.0:
  including all previous fixes, a small memory leak fix in jack
  plugin
- Dropped patches:
  0001-rate-Allow-LGPL-for-libsamplerate-commercial-license.patch
  0002-mix-Fix-extplug-version-ifdef-checks.patch
  0003-a52-Fix-ioplug-version-ifdef-checks.patch
  0004-pulse-Add-24-bit-data-formats-to-Pulse-plugin.patch
  0005-arcam-av-Include-sys-select.h-for-fd_set-definition.patch
  0006-pph-include-speexdsp_types.h-not-speex_types.h.patch
  0007-pph-Fix-build-with-older-speex.patch
* Thu Jul  9 2015 tiwai@suse.de
- Backport upstream fixes: just minor build fix issues that don't
  hit us, but kept here for consistency
  0005-arcam-av-Include-sys-select.h-for-fd_set-definition.patch
  0006-pph-include-speexdsp_types.h-not-speex_types.h.patch
  0007-pph-Fix-build-with-older-speex.patch
- Fix build error with SLE11-SP3 due to lack of speexdsp pkgconfig.
* Fri May 22 2015 tiwai@suse.de
- Backport upstream fixes: fixes for A52 plugin, mix plugin protocol
  version fix, and enhancement for JACK plugin to support 24bit
  formats:
  0001-rate-Allow-LGPL-for-libsamplerate-commercial-license.patch
  0002-mix-Fix-extplug-version-ifdef-checks.patch
  0003-a52-Fix-ioplug-version-ifdef-checks.patch
  0004-pulse-Add-24-bit-data-formats-to-Pulse-plugin.patch
* Thu Mar 12 2015 dimstar@opensuse.org
- BuildRequire pkgconfig(speexdsp) instead of speex-devel: the
  packages have been rearranged/split.
- Add alsa-plugins-include-config.h.patch: Fix build with new
  speexdsp versions. The speexdsp headers expect the caller to set
  HAVE_STDINT_H (or any of the other appropriate headers, based on
  platform) in order to define the specific types.
* Thu Feb 26 2015 tiwai@suse.de
- Update to alsa-plugins 1.0.29:
  Just a version bump including previous fixes
- Drop obsoleted patch:
  0001-jack-Restore-PID-to-jack-client-name-when-not-specif.patch
* Sun Nov  9 2014 ledest@gmail.com
- fix bashisms in post/postun scripts:
  option '-p' of 'type' command may be unsupported is some shells,
  use 'command -v' instead
* Tue Aug 12 2014 tiwai@suse.de
- Backport upstream fix for backward compatibility of jack PCM
  plugin:
  0001-jack-Restore-PID-to-jack-client-name-when-not-specif.patch
* Wed Jun 18 2014 tiwai@suse.de
- Updated to alsa-plugins 1.0.28:
  All pervious fix patches are obsoleted:
  0001-Check-for-and-include-libavutil.h-to-avoid-unresolve.patch
  0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
  0003-vdownmix-Add-chmap-support.patch
  0004-upmix-Add-chmap-support.patch
  0005-a52-Fix-build-error-with-the-recent-version.patch
  0006-a52-Add-chmap-support.patch
  0007-a52-Propagate-errors-from-hw.patch
  0008-a52-switch-to-AV_CODEC_ID-identifiers.patch
  0009-jack-Allow-to-specify-a-client-name-as-parameters.patch
* Tue Mar 11 2014 tiwai@suse.de
- Backport upstream fixes: add chmap support to plugins, fix a52
  builds, add a new option to jack plugin:
  0003-vdownmix-Add-chmap-support.patch
  0004-upmix-Add-chmap-support.patch
  0005-a52-Fix-build-error-with-the-recent-version.patch
  0006-a52-Add-chmap-support.patch
  0007-a52-Propagate-errors-from-hw.patch
  0008-a52-switch-to-AV_CODEC_ID-identifiers.patch
  0009-jack-Allow-to-specify-a-client-name-as-parameters.patch
- Run spec-cleaner
* Thu May 23 2013 tiwai@suse.de
- Backport upstream fixes:
  0001-Check-for-and-include-libavutil.h-to-avoid-unresolve.patch
  0002-Add-AM_MAINTAINER_MODE-enable-to-configure.in.patch
* Fri Apr 12 2013 tiwai@suse.de
- Updated to version 1.0.27:
  including all previous fixes; all 00*-* patches dropped
* Mon Mar 11 2013 tiwai@suse.de
- Backport fix patches from upstream:
  0002-a52-Add-the-support-of-recent-libavcodec-libavutil.patch
  0003-a52-Fix-build-errors.patch
  0004-pulse-pulse_pcm_poll_revents-should-return-0-on-succ.patch
* Fri Feb  1 2013 tiwai@suse.de
- Correct the package version number to 1.0.26; no content change
* Fri Nov 30 2012 tiwai@suse.de
- Improve prebuf setup of pulse plugin:
  0001-pcm_pulse-set-prebuf-parameter-according-to-software.patch
* Fri Oct 26 2012 tiwai@suse.de
- remove obsoleted alsa-plugins-include.patch
* Fri Sep  7 2012 tiwai@suse.de
- Updated to version 1.0.26:
  including glibc-2.16 build fix, add support 24bit format to pulse
* Thu Sep  6 2012 tiwai@suse.de
- Add post/postun hooks for pulse plugin to fix the leftover
  config path (bnc#779039)
* Sun Jul 29 2012 aj@suse.de
- Move _GNU_SOURCE before any header inclusion to fix build with glibc 2.16
* Sat Mar 31 2012 reddwarf@opensuse.org
- stop recommending -32bit packages
* Wed Jan 25 2012 tiwai@suse.de
- updated to version 1.0.25; including all previous fixes
* Fri Sep 30 2011 coolo@suse.com
- add libtool as buildrequire to make the spec file more reliable
* Tue Sep 27 2011 tiwai@suse.de
- Set CLOEXEC flag to left-over fds in pulse plugin
* Tue Sep 20 2011 tiwai@suse.de
- Install pulse plugin setup in the new config.d directory,
  use the upstream default
* Sat Sep 17 2011 jengelh@medozas.de
- Remove redundant tags/sections from specfile
- Use %%_smp_mflags for parallel build
* Fri Aug 26 2011 tiwai@suse.de
- Fix the build of pulse plugin with a very old PA
* Fri Aug 26 2011 tiwai@suse.de
- Add a better overrun handling with the new PA API
* Mon Aug  8 2011 tiwai@suse.de
- Fix hanging applications when using jack plugin
* Wed Jul 27 2011 tiwai@suse.de
- Add PA_CONTEXT_NOAUTOSPAWN flag when fallback is set for pulse
  plugins
* Tue Jul 26 2011 tiwai@suse.de
- Add fallback option to pulse plugin
- Enable the fallback to the system-default in asound-pulse.conf
* Tue Apr 26 2011 tiwai@suse.de
- Upstream fixes:
  * Fix build of a52 plugin (not used in this package, though)
  * Fix bogus snd_pcm_avail() zero return in pulse plugin
* Mon Jan 31 2011 tiwai@suse.de
- Updated to version 1.0.24:
  * including previous fixes
  * Fix documents
* Thu Sep  2 2010 tiwai@suse.de
- Backport upstream fix:
  pulse: Add handle_underrun option
* Thu Jun 24 2010 tiwai@suse.de
- Backport upstream fix:
  pulse: Fix invalid buffer pointer return value
* Mon Apr 19 2010 tiwai@suse.de
- updated to version 1.0.23:
  * including previous fixes
* Mon Mar  8 2010 tiwai@suse.de
- Backport upstream fixes:
  * usb_stream: Check for NULL-ness before dereferencing
  * usb_stream: Allow user-set period-size and rate
* Wed Jan 27 2010 jengelh@medozas.de
- package baselibs.conf
* Fri Dec 18 2009 tiwai@suse.de
- set AUTOMAKE_JOBS for parallel automake
* Fri Dec 18 2009 tiwai@suse.de
- updated to version 1.0.22:
  * upmix 7.1 channels support
  * fixes for a53 with recent libavcodec
* Wed Sep  9 2009 tiwai@suse.de
- add recommends tags for 32bit packages (bnc#537555)
* Mon Aug 31 2009 tiwai@suse.de
- updated to version 1.0.21:
  just a version bump including previous fixes
* Fri Aug  7 2009 tiwai@suse.de
- yet another updates of pulse plugin:
  * replace manual mainloop by pa_mainloop_iterate()
  * move a couple of PCM related functions from pulse.c to pcm_pulse.c
  * get rid of redundant state variable
  * unify stream/context state checks
  * rework object destruction paths a bit
  * immediately trigger EIO when connection is dropped
* Mon Aug  3 2009 tiwai@suse.de
- update pulse plugin:
  * get rid of a number of assert()s
  * unify destruction of snd_pulse_t
  * use PA_CONTEXT_IS_GOOD where applicable
  * call pa_threaded_mainloop_wait() to handle spurious wakeups
* Thu Jul 30 2009 sbrabec@suse.cz
- alsa-plugin-pulse does not work without pulseaudio, add Requires.
* Fri Jul 17 2009 tiwai@suse.de
- fix the missing initialization of OSS PCM plugin
* Fri Jun 19 2009 tiwai@suse.de
- echo-cancelling support in speex dsp plugin
* Tue Jun  2 2009 tiwai@suse.de
- extend rate plugins to follow the new protocol
* Wed May  6 2009 tiwai@suse.de
- updated to version 1.0.20:
  * including previous patches
  * arcam-av plugin updates
* Tue Feb 17 2009 tiwai@suse.de
- add the support of non-zero numid in external ctl plugins
  (bnc#462032)
* Thu Jan 22 2009 tiwai@suse.de
- updated to version 1.0.19:
  * just minor updates
- added speex pre-processing plugin
- added arcam-av control plugin
- fix spec file to be compatible with older distro
* Wed Oct 29 2008 tiwai@suse.de
- updated to version 1.0.18-final;
  just including all previous fixes
* Wed Oct 15 2008 tiwai@suse.de
- Fix pulse plugin issues:
  * broken capture returning -EIO (bnc#435058)
  * small memory leak
* Wed Sep 10 2008 tiwai@suse.de
- updated to version 1.0.18rc3:
  * code cleanup in pulse pcm plugin
  * fix poll handling in pulse pcm
  * fix S32/FLOAT32 format support in pulse
  * use PA_STREAM_EARLY_REQUEST
  * fix channel mappings, buffer metrics
* Tue Aug 26 2008 tiwai@suse.de
- fix build with recent ffmpeg
* Mon Aug 18 2008 tiwai@suse.de
- updated to version 1.0.18-rc2:
  including previous fixes and additions
* Wed Aug  6 2008 tiwai@suse.de
- updated to git snapshot 20080806:
  * added usb-stream PCM plugin for US122L devices
- add config tag to pulse-related config files
* Mon Jul 28 2008 tiwai@suse.de
- fix slient output of short streams (bnc#409645)
* Wed Jul 16 2008 tiwai@suse.de
- don't use assert() for sanity checks (bnc#409532)
* Tue Jul 15 2008 tiwai@suse.de
- updated to version 1.0.17-final:
  * just a version bump
* Wed Jun 18 2008 tiwai@suse.de
- updated to version 1.0.17rc2:
  * including last fixes
* Fri Jun  6 2008 tiwai@suse.de
- use plug layer for pulse defult PCM (bnc#397523)
  this requires the fix in alsa-lib, too
* Wed Jun  4 2008 rodrigo@suse.de
- Added alsa-pulse.conf as configuration file for GNOME installs
  (bnc#394177)
* Mon Jun  2 2008 meissner@suse.de
- added baselibs.conf, so 32bit programs get the pulse-alsa
  wrapper plugin too.
* Mon May 26 2008 rodrigo@suse.de
- Removed dependency on pulseaudio, pulseaudio package now depends
  on alsa-plugins-pulse to fix bnc#394177
* Mon May 26 2008 rodrigo@suse.de
- Added asound-pulse.conf to contain configuration for the ALSA
  PulseAudio plugin (bnc#394177)
* Mon Mar 10 2008 tiwai@suse.de
- remove some useless asserts in pulse plugin that cause crashes
* Fri Feb  8 2008 tiwai@suse.de
- updated to version 1.0.16-final:
  * just a version bump
* Tue Jan 22 2008 tiwai@suse.de
- updated to version 1.0.16rc1:
  * just a version bump
* Fri Jan 11 2008 rodrigo@suse.de
- Depend on libpulse-devel, not pulseaudio-devel
* Fri Dec 14 2007 tiwai@suse.de
- several bug fixes for pulse plugin
  * fix buffer size handling
  * handle XRUN properly (requireing the latest alsa-lib)
* Mon Oct 29 2007 tiwai@suse.de
- fix invalid assert call in pulse plugin
* Tue Oct 16 2007 tiwai@suse.de
- updated to version 1.0.15:
  * including all previous fixes
* Tue Aug 14 2007 tiwai@suse.de
- Fix speex resampler plugin bugs
* Mon Jul 30 2007 tiwai@suse.de
- HG patch (as of 2007.07.28)
  * build modules with -no-undefined option
  * fix speex resampler bug in 4times upsampling
  * fix the noise at beginning of playback with samplerate
    plugin
* Tue Jun  5 2007 tiwai@suse.de
- updated to version 1.0.14-final:
  including previous HG fixes
* Thu May 24 2007 tiwai@suse.de
- HG snapshot as of 2007.05.24:
  * configure option to specify plugin directory
  * possible to link with external libspeex
* Wed May  2 2007 tiwai@suse.de
- updated to version 1.0.14rc4:
  including HG fixes
* Tue Apr 10 2007 tiwai@suse.de
- split samplerate to subpackage (the sole GPL-only module).
- fixed licenses on PDB.
* Tue Apr  3 2007 tiwai@suse.de
- Add explicitly jack and pulseaudio to Requires of each sub
  package.
* Wed Mar 14 2007 tiwai@suse.de
- updated to version 1.0.14rc3:
  * fix input/output_frames calculation in samplerate plugin
  * added speex rsampler plugin
* Thu Feb  8 2007 tiwai@suse.de
- update to version 1.0.14rc2 - just repackaging from 1.0.14rc1a
- split internal sub package to its own spec file
* Tue Dec 19 2006 tiwai@suse.de
- updated to version 1.0.14rc1:
  * clean up polyp plugin
  * added maemo plugin
- add conditional for internal build (#224415)
* Fri Aug  4 2006 tiwai@suse.de
- updated to version 1.0.12rc2:
  the previous patches were merged to upstream
* Wed Jul 12 2006 tiwai@suse.de
- rename from polyp to pulse plugin, as polypaudio is renamed
  to pulseaudio.
* Tue Jul  4 2006 tiwai@suse.de
- updated to version 1.0.12rc1:
  the previous HG patches were merged
* Thu Jun  8 2006 tiwai@suse.de
- new plugins: polyp and a52
- split to sub-packages: jack, polyp and a52
* Mon May 15 2006 tiwai@suse.de
- updated to version 1.0.11.
  * new samplerate plugins
  * misc bugfixes for JACK plugins
* Wed Jan 25 2006 mls@suse.de
- converted neededforbuild to BuildRequires
* Wed Dec 14 2005 tiwai@suse.de
- updated to 1.0.10-final.
* Wed Oct 12 2005 tiwai@suse.de
- removed glib* from neededforbuild.
* Wed Oct 12 2005 tiwai@suse.de
- updated to version 1.0.10rc1.
* Thu Jun  2 2005 tiwai@suse.de
- initial version: 1.0.9.
